/*----------------------------------------------------------------------------------------------------------*/
/* create a fresh copy of the database, including objects													*/
/*----------------------------------------------------------------------------------------------------------*/
CREATE DATABASE [dbcc_checkconstraints_error_446_fresh]
COLLATE Latin1_General_BIN
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET COMPATIBILITY_LEVEL = 110
GO

IF (1 = FULLTEXTSERVICEPROPERTY('IsFullTextInstalled'))
begin
EXEC [dbcc_checkconstraints_error_446_fresh].[dbo].[sp_fulltext_database] @action = 'enable'
end
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET ANSI_NULL_DEFAULT OFF 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET ANSI_NULLS ON 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET ANSI_PADDING ON 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET ANSI_WARNINGS ON 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET ARITHABORT ON 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET AUTO_CLOSE OFF 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET AUTO_CREATE_STATISTICS ON 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET AUTO_SHRINK OFF 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET AUTO_UPDATE_STATISTICS ON 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET CURSOR_CLOSE_ON_COMMIT OFF 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET CURSOR_DEFAULT  GLOBAL 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET CONCAT_NULL_YIELDS_NULL ON 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET NUMERIC_ROUNDABORT OFF 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET QUOTED_IDENTIFIER ON 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET RECURSIVE_TRIGGERS OFF 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET  DISABLE_BROKER 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET AUTO_UPDATE_STATISTICS_ASYNC ON 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET DATE_CORRELATION_OPTIMIZATION OFF 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET TRUSTWORTHY OFF 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET ALLOW_SNAPSHOT_ISOLATION OFF 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET PARAMETERIZATION SIMPLE 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET READ_COMMITTED_SNAPSHOT OFF 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET HONOR_BROKER_PRIORITY OFF 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET RECOVERY SIMPLE 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET  MULTI_USER 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET PAGE_VERIFY CHECKSUM  
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET DB_CHAINING OFF 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET FILESTREAM( NON_TRANSACTED_ACCESS = OFF ) 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET TARGET_RECOVERY_TIME = 0 SECONDS 
GO

ALTER DATABASE [dbcc_checkconstraints_error_446_fresh] SET  READ_WRITE 
GO


/*----------------------------------------------------------------------------------------------------------*/
USE [dbcc_checkconstraints_error_446_fresh]
GO

/*----------------------------------------------------------------------------------------------------------*/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [dbo].[ActiveConference](
	[ConfId] [int] NOT NULL,
	[ConfStateVersion] [int] NOT NULL,
	[Locked] [bit] NOT NULL,
	[AdmissionType] [tinyint] NOT NULL,
	[Autopromote] [tinyint] NOT NULL,
	[PstnLobbyBypass] [bit] NOT NULL,
	[LastPartId] [int] NOT NULL,
	[LastEnterprisePartLeaveTime] [datetime] NOT NULL,
	[ActivationInstance] [uniqueidentifier] NOT NULL,
	[IsLargeMeeting] [bit] NOT NULL,
 CONSTRAINT [PK_ActiveConference] PRIMARY KEY CLUSTERED 
(
	[ConfId] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]

GO

ALTER TABLE [dbo].[ActiveConference]  WITH CHECK ADD CHECK  (([AdmissionType]=(3) OR [AdmissionType]=(2) OR [AdmissionType]=(1)))
GO

ALTER TABLE [dbo].[ActiveConference]  WITH CHECK ADD CHECK  (([Autopromote]=(2) OR [Autopromote]=(1) OR [Autopromote]=(0)))
GO


/*----------------------------------------------------------------------------------------------------------*/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

SET ANSI_PADDING ON
GO

CREATE TABLE [dbo].[Participant](
	[ConfId] [int] NOT NULL,
	[PartId] [int] NOT NULL,
	[UserAtHostCksum] [int] NOT NULL,
	[UserAtHost] [nvarchar](450) NOT NULL,
	[EnterpriseId] [int] NULL,
	[DisplayName] [varbinary](256) NOT NULL,
	[RoleId] [int] NOT NULL,
	[Privilege] [tinyint] NOT NULL,
	[AuthZ] [char](1) NOT NULL,
	[JoinTime] [datetime] NOT NULL,
	[IsBypassed] [bit] NOT NULL,
	[Endorser] [nvarchar](450) NULL,
	[EndorserDisplayName] [varbinary](256) NULL,
 CONSTRAINT [PK_Participant] PRIMARY KEY CLUSTERED 
(
	[ConfId] ASC,
	[PartId] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]

GO

SET ANSI_PADDING ON
GO

ALTER TABLE [dbo].[Participant]  WITH CHECK ADD  CONSTRAINT [FK_Participant_1] FOREIGN KEY([ConfId])
REFERENCES [dbo].[ActiveConference] ([ConfId])
GO

ALTER TABLE [dbo].[Participant] CHECK CONSTRAINT [FK_Participant_1]
GO

ALTER TABLE [dbo].[Participant]  WITH CHECK ADD CHECK  (([AuthZ]='P' OR [AuthZ]='A'))
GO

ALTER TABLE [dbo].[Participant]  WITH CHECK ADD CHECK  (([Privilege]=(1) OR [Privilege]=(0)))
GO

ALTER TABLE [dbo].[Participant]  WITH CHECK ADD CHECK  ((charindex(N'@',[UserAtHost])<>(0)))
GO

CREATE NONCLUSTERED INDEX [IX_Participant_EnterpriseId] ON [dbo].[Participant]
(
	[ConfId] ASC,
	[EnterpriseId] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO

CREATE NONCLUSTERED INDEX [IX_Participant_UserAtHostCksum] ON [dbo].[Participant]
(
	[ConfId] ASC,
	[UserAtHostCksum] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
GO


/*----------------------------------------------------------------------------------------------------------*/
INSERT	INTO [dbo].[ActiveConference]([ConfId],[ConfStateVersion],[Locked],[AdmissionType],[Autopromote],[PstnLobbyBypass],[LastPartId],[LastEnterprisePartLeaveTime],[ActivationInstance],[IsLargeMeeting])
		VALUES(1,1,0,1,1,0,1,getdate(),newid(),0)
GO


INSERT	INTO [dbo].[Participant]([ConfId],[PartId],[UserAtHostCksum],[UserAtHost],[EnterpriseId],[DisplayName],[RoleId],[Privilege],[AuthZ],[JoinTime],[IsBypassed],[Endorser],[EndorserDisplayName])
		VALUES(1,1,1,'@a',1,cast('a' as varbinary),1,1,'A',getdate(),0,'a',cast('a' as varbinary))
GO

DELETE FROM [dbo].[Participant]
GO

DELETE FROM [dbo].[ActiveConference]
GO


/*----------------------------------------------------------------------------------------------------------*/
DBCC CHECKCONSTRAINTS('[dbo].[Participant]')
GO
